summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
authorJosh Haberman <jhaberman@gmail.com>2014-02-04 15:43:52 -0800
committerJosh Haberman <jhaberman@gmail.com>2014-02-04 15:43:52 -0800
commit7d565f1e7a0f107506d3cf31ef2e33e22a504d2b (patch)
tree151a5102b0ded6e8ad098a86e692c1d14e390167 /tools
parent0fd2f830882402979a83010e89650e7245960d39 (diff)
Sync from Google development.
Diffstat (limited to 'tools')
-rw-r--r--tools/dump_cinit.lua13
1 files changed, 7 insertions, 6 deletions
diff --git a/tools/dump_cinit.lua b/tools/dump_cinit.lua
index e23e907..c3104ee 100644
--- a/tools/dump_cinit.lua
+++ b/tools/dump_cinit.lua
@@ -359,15 +359,16 @@ local function dump_defs_c(symtab, basename, append)
else
intfmt = "0"
end
- -- UPB_FIELDDEF_INIT(label, type, intfmt, tagdelim, is_extension, name,
- -- num, msgdef, subdef, selector_base, index,
+ -- UPB_FIELDDEF_INIT(label, type, intfmt, tagdelim, is_extension, lazy,
+ -- name, num, msgdef, subdef, selector_base, index,
-- default_value)
- append(' UPB_FIELDDEF_INIT(%s, %s, %s, %s, %s, "%s", %d, %s, %s, %d, ' ..
- '%d, {0},' .. -- TODO: support default value
+ append(' UPB_FIELDDEF_INIT(%s, %s, %s, %s, %s, %s, "%s", %d, %s, %s, ' ..
+ '%d, %d, {0},' .. -- TODO: support default value
'&reftables[%d], &reftables[%d]),\n',
const(f, "label"), const(f, "type"), intfmt,
- boolstr(f:istagdelim()), boolstr(f:is_extension()), f:name(),
- f:number(), linktab:addr(f:containing_type()), subdef,
+ boolstr(f:istagdelim()), boolstr(f:is_extension()),
+ boolstr(f:lazy()), f:name(), f:number(),
+ linktab:addr(f:containing_type()), subdef,
f:_selector_base(), f:index(),
reftable, reftable + 1
)
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback